#
# spec file for package charybdis
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           charybdis
Version:        3.5.3
Release:        lp151.2.5
Summary:        Scalable IRCv3.2 compliant chat daemon
License:        GPL-2.0+
Group:          Productivity/Networking/IRC
Url:            http://atheme.org/projects/charybdis.html

#Git-Clone:	https://github.com/charybdis-ircd/charybdis
Source:         https://github.com/charybdis-ircd/charybdis/archive/%name-%version.tar.gz
Source9:        example.conf
Patch1:         charybdis-ratbox.diff
Patch2:         charybdis-werror.diff
Patch3:         charybdis-repro.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libcrypto) >= 0.9.7
BuildRequires:  pkgconfig(libssl) >= 0.9.7
BuildRequires:  pkgconfig(zlib)
Requires(pre):  shadow

%description
Charybdis is the IRCv3 reference implementation. It has good
documentation and ease of configuration.

Charybdis is used on various networks either as itself, or as the
basis of a customized IRC server implementation. One such
customization is ircd-seven which powers Freenode, the largest IRC
network in the world.

%prep
%setup -qn %name-%name-%version
%patch -P 1 -P 2 -P 3 -p1

%build
autoreconf -fiv
%configure --sysconfdir="%_sysconfdir/%name" \
	--with-logdir="%_localstatedir/log/%name" \
	--with-rundir="/run" --localstatedir="%_localstatedir/lib"
make %{?_smp_mflags} CHARYBDIS_VERSION="%version"

%install
b="%buildroot"
%make_install
mv "$b/%_bindir"/* "$b/%_libexecdir/%name/"
find "$b/%_libdir" -type f -name "*.la" -delete

# Unconflict with other ircds.
mv "$b/%_mandir/man8"/{ircd,charybdis-ircd}.8
# Move config file samples/documentation out of the way
mv "$b/%_sysconfdir/%name"/*.conf "$b/%_datadir/%name/"
# Place some config file that will make it run out of the box on localhost
cp "%{S:9}" "$b/%_sysconfdir/%name/ircd.conf"

mkdir -p "$b/%_localstatedir/lib/charybdis" \
	"$b/%_localstatedir/log/charybdis" "$b/%_sbindir" \
	"$b/%_unitdir" "$b/%_prefix/lib/tmpfiles.d"
ln -s service "$b/%_sbindir/rc%name"
cat >"$b/%_unitdir/charybdis.service" <<-EOF
	[Unit]
	Description=Charybdis Inter Relay Chat server
	[Service]
	ExecStart=%_libexecdir/%name/ircd -foreground
	User=charybdis
	Group=charybdis
	[Install]
	WantedBy=multi-user.target
EOF
cat >"$b/%_prefix/lib/tmpfiles.d/charybdis.conf" <<-EOF
	d /run/%name 0755 charybdis charybdis -
EOF
# There are no headers installed, so the .pc and devel .so is useless
rm -Rf "$b/%_libdir/pkgconfig" "$b/%_libdir/libratbox.so"

%pre
getent group charybdis >/dev/null || \
	/usr/sbin/groupadd -r charybdis
getent passwd charybdis >/dev/null || \
	/usr/sbin/useradd -r -g charybdis -s /bin/false \
	-c "Charybdis Inter Relay Chat daemon" \
	-d "%_localstatedir/lib/charybdis" charybdis
%service_add_pre %name.service

%post
%service_add_post %name.service
systemd-tmpfiles --create %name.conf || :

%preun
%service_del_preun %name.service

%postun
%service_del_postun %name.service

%files
%defattr(-,root,root)
%attr(0750,root,charybdis) %dir %_sysconfdir/%name
%attr(0640,root,charybdis) %config %_sysconfdir/%name/*
%_sbindir/rc%name
%_libexecdir/%name/
%_libdir/%name/
%_libdir/libratbox-charybdis.so
%_datadir/%name/
%_mandir/man8/*.8*
%_prefix/lib/tmpfiles.d/
%_unitdir/*.service
%attr(0750,charybdis,charybdis) %_localstatedir/log/%name/
%attr(0750,charybdis,charybdis) %_localstatedir/lib/%name/
%doc LICENSE NEWS.md

%changelog
* Tue Jan 10 2017 jengelh@inai.de
- Add charybdis-repro.diff, throw out buildtime-dependent
  constructs
* Sun Nov 20 2016 jengelh@inai.de
- Update description
- Abort installation if user/group cannot be created
* Wed Sep 21 2016 jengelh@inai.de
- Update to new upstream release 3.5.3
  * Bug fix for CVE-2016-7143. This bug allows users to spoof CertFP
  authentication using the SASL EXTERNAL mechanism.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 3.5.2
  * Allow IRCv3.1 STARTTLS to work with other SSL backends besides
  OpenSSL.
  * Fix an edge case regression involving channel ban cache that was
  introduced in 3.5.0.
  * Ensure ssld does not crash when DH parameters are not provided.
  * mbedtls TLS backend improvements from charybdis 4 development
  branch:
  * add support for CertFP
  * provide personalization data for the PRNG
  * openssl TLS backend improvements from charybdis 4:
  * do not manually initialise openssl when running with OpenSSL
  1.1.0 or later
  * support ECDHE on more than one curve on OpenSSL 1.0.2 and above
  * fix DH parameters memory leak
  * free the old TLS context before constructing a new one
* Sat May  7 2016 jengelh@inai.de
- Update to new upstream release 3.5.1
  * Fix propagation of ip_cloaking hostname changes (only when
  setting or unsetting the umode after connection).
  * Fix a remote-triggerable crash triggered by the CAPAB parsing
  code.
  * As per the TS6 spec, require QS and ENCAP capabilities.
  * Require EX and IE capabilities (+e and +I cmodes).
  * Check that UIDs start with the server's SID.
  * Allow mode queries on mlocked modes. In particular, allow
  `/mode #channel f` to query the forward channel even if
  +f is mlocked.
  * Add starttls as per ircv3.
  * Reject nicks with '~' in them, rather than truncating at the '~'.
  * Do not allow SASL authentication when the configured SASL agent
  is unavailable.
  * Implement IRCv3.2 capabilities: cap-notify, chghost,
  userhost-in-names
  * Implement the $&, $| and $m extban types:
  * $& combines 1 or more child extbans as an AND expression
  * $| combines 1 or more child extbans as an OR expression
  * $m provides normal hostmask matching as an extban for the above
  * Display an operator's privilege set in WHOIS.
  * The $o extban now matches against privilege set names as well as
  individual privileges. Privilege set names are preferred over
  individual privileges.
* Mon Oct  6 2014 jengelh@inai.de
- Update to new upstream release 3.4.2
  * A new extban, $z, has been added for ssl users (extb_ssl)
  * Remove TS5 support
  * Replace oper flags by privilege sets (privsets)
  * Add cmode +C (no CTCP) from ircd-seven.
  * Add bandb from ircd-ratbox, which stores permanent
  [DKX]lines/resvs in an sqlite database instead of a flatfile
- Add charybdis-ratbox.diff, charybdis-werror.diff
* Sun Oct 28 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Feed through format_spec_file service
- Add systemd service file
* Sun Sep 30 2007 mrueckert@suse.de
- update to version 2.2.0
- also build the unsupported modules
* Sat Apr 14 2007 mrueckert@suse.de
- update to version 2.1.3
* Sat Apr 14 2007 mrueckert@suse.de
- fix build requires for factory
- add missing %%dir entry
* Mon Nov 27 2006 mrueckert@suse.de
- use assembler stuff only on ix86
* Mon Nov 27 2006 mrueckert@suse.de
- initial package.
